@@ -8,7 +8,6 @@ This module inherits constants for Denon AVR receivers.
 """
 
 import re
-
 from collections import namedtuple
 
 import attr
@@ -20,19 +19,38 @@ DENON_ATTR_SETATTR = [attr.setters.validate, attr.setters.convert]
 ReceiverType = namedtuple("ReceiverType", ["type", "port"])
 DescriptionType = namedtuple("DescriptionType", ["port", "url"])
 ReceiverURLs = namedtuple(
-    "ReceiverURLs", [
-        "appcommand", "appcommand0300", "status", "mainzone", "deviceinfo",
-        "netaudiostatus", "tunerstatus", "hdtunerstatus", "command_sel_src",
-        "command_fav_src", "command_power_on", "command_power_standby",
-        "command_volume_up", "command_volume_down", "command_set_volume",
-        "command_mute_on", "command_mute_off", "command_sel_sound_mode",
-        "command_netaudio_post", "command_set_all_zone_stereo",
-        "command_pause", "command_play"])
+    "ReceiverURLs",
+    [
+        "appcommand",
+        "appcommand0300",
+        "status",
+        "mainzone",
+        "deviceinfo",
+        "netaudiostatus",
+        "tunerstatus",
+        "hdtunerstatus",
+        "command_sel_src",
+        "command_fav_src",
+        "command_power_on",
+        "command_power_standby",
+        "command_volume_up",
+        "command_volume_down",
+        "command_set_volume",
+        "command_mute_on",
+        "command_mute_off",
+        "command_sel_sound_mode",
+        "command_netaudio_post",
+        "command_set_all_zone_stereo",
+        "command_pause",
+        "command_play",
+    ],
+)
 
 # AVR-X search patterns
 DEVICEINFO_AVR_X_PATTERN = re.compile(
     r"(.*AV(C|R)-(X|S).*|.*SR500[6-9]|.*SR60(07|08|09|10|11|12|13)|."
-    r"*SR70(07|08|09|10|11|12|13)|.*SR501[3-4]|.*NR1604|.*NR1710)")
+    r"*SR70(07|08|09|10|11|12|13)|.*SR501[3-4]|.*NR1604|.*NR1710)"
+)
 
 DEVICEINFO_COMMAPI_PATTERN = re.compile(r"(0210|0220|0250|0300|0301)")
 
@@ -50,38 +68,113 @@ DESCRIPTION_TYPES = {
     AVR_NAME: DescriptionType(port=8080, url="/description.xml"),
     AVR_X_NAME: DescriptionType(port=8080, url="/description.xml"),
     AVR_X_2016_NAME: DescriptionType(
-        port=60006, url="/upnp/desc/aios_device/aios_device.xml")}
+        port=60006, url="/upnp/desc/aios_device/aios_device.xml"
+    ),
+}
 
 SOURCE_MAPPING = {
-    "TV AUDIO": "TV", "iPod/USB": "USB/IPOD", "Bluetooth": "BT",
-    "Blu-ray": "BD", "CBL/SAT": "SAT/CBL", "NETWORK": "NET",
-    "Media Player": "MPLAY", "AUX": "AUX1", "Tuner": "TUNER",
-    "FM": "TUNER", "SpotifyConnect": "Spotify Connect"}
+    "TV AUDIO": "TV",
+    "iPod/USB": "USB/IPOD",
+    "Bluetooth": "BT",
+    "Blu-ray": "BD",
+    "CBL/SAT": "SAT/CBL",
+    "NETWORK": "NET",
+    "Media Player": "MPLAY",
+    "AUX": "AUX1",
+    "Tuner": "TUNER",
+    "FM": "TUNER",
+    "SpotifyConnect": "Spotify Connect",
+}
 
-CHANGE_INPUT_MAPPING = {"Internet Radio": "IRP", "Online Music": "NET",
-                        "Media Server": "SERVER", "Spotify": "SPOTIFY",
-                        "Flickr": "FLICKR", "Favorites": "FAVORITES"}
+CHANGE_INPUT_MAPPING = {
+    "Favorites": "FAVORITES",
+    "Flickr": "FLICKR",
+    "Internet Radio": "IRADIO",
+    "Media Server": "SERVER",
+    "Online Music": "NET",
+    "Spotify": "SPOTIFY",
+}
 
-TELNET_SOURCES = ["CD", "PHONO", "TUNER", "DVD", "BD", "TV",
-                  "SAT/CBL", "MPLAY", "GAME", "HDRADIO", "NET", "PANDORA",
-                  "SIRIUSXM", "LASTFM", "FLICKR", "IRADIO", "SERVER",
-                  "FAVORITES", "AUX1", "AUX2", "AUX3", "AUX4", "AUX5",
-                  "AUX6", "AUX7", "BT", "USB/IPOD", "USB DIRECT",
-                  "IPOD DIRECT"]
+TELNET_SOURCES = [
+    "CD",
+    "PHONO",
+    "TUNER",
+    "DVD",
+    "BD",
+    "TV",
+    "SAT/CBL",
+    "MPLAY",
+    "GAME",
+    "HDRADIO",
+    "NET",
+    "PANDORA",
+    "SIRIUSXM",
+    "LASTFM",
+    "FLICKR",
+    "IRADIO",
+    "IRP",
+    "SERVER",
+    "FAVORITES",
+    "AUX1",
+    "AUX2",
+    "AUX3",
+    "AUX4",
+    "AUX5",
+    "AUX6",
+    "AUX7",
+    "BT",
+    "USB/IPOD",
+    "USB DIRECT",
+    "IPOD DIRECT",
+]
+
+TELNET_MAPPING = {
+    "FAVORITES": "Favorites",
+    "FLICKR": "Flickr",
+    "IRADIO": "Internet Radio",
+    "IRP": "Internet Radio",
+    "SERVER": "Media Server",
+    "SPOTIFY": "Spotify",
+}
 
 # Sound modes
 ALL_ZONE_STEREO = "ALL ZONE STEREO"
 
 SOUND_MODE_MAPPING = {
-    "MUSIC": ["PLII MUSIC", "DTS NEO:6 MUSIC", "DTS NEO:6 M",
-              "DOLBY D +NEO:X M", "DTS NEO:X MUSIC", "DOLBY PL2 MUSIC",
-              "DOLBY PL2 M", "PLIIX MUSIC", "DOLBY PL2 X MUSIC"],
-    "MOVIE": ["PLII MOVIE", "PLII CINEMA", "DTS NEO:X CINEMA",
-              "DTS NEO:6 CINEMA", "DTS NEO:6 C", "DOLBY D +NEO:X C",
-              "PLIIX CINEMA", "DOLBY PLII MOVIE", "MULTI IN + VIRTUAL:X",
-              "DOLBY PL2 CINEMA", "DOLBY PL2 C", "DOLBY PL2 X MOVIE"],
-    "GAME": ["PLII GAME", "DOLBY D +NEO:X G", "DOLBY PL2 GAME", "DOLBY PL2 G",
-             "DOLBY PL2 X GAME"],
+    "MUSIC": [
+        "PLII MUSIC",
+        "DTS NEO:6 MUSIC",
+        "DTS NEO:6 M",
+        "DTS NEO:X M",
+        "DOLBY D +NEO:X M",
+        "DTS NEO:X MUSIC",
+        "DOLBY PL2 MUSIC",
+        "DOLBY PL2 M",
+        "PLIIX MUSIC",
+        "DOLBY PL2 X MUSIC",
+    ],
+    "MOVIE": [
+        "PLII MOVIE",
+        "PLII CINEMA",
+        "DTS NEO:X CINEMA",
+        "DTS NEO:X C",
+        "DTS NEO:6 CINEMA",
+        "DTS NEO:6 C",
+        "DOLBY D +NEO:X C",
+        "PLIIX CINEMA",
+        "DOLBY PLII MOVIE",
+        "MULTI IN + VIRTUAL:X",
+        "DOLBY PL2 CINEMA",
+        "DOLBY PL2 C",
+        "DOLBY PL2 X MOVIE",
+    ],
+    "GAME": [
+        "PLII GAME",
+        "DOLBY D +NEO:X G",
+        "DOLBY PL2 GAME",
+        "DOLBY PL2 G",
+        "DOLBY PL2 X GAME",
+    ],
     "AUTO": ["None"],
     "STANDARD": ["None2"],
     "VIRTUAL": ["VIRTUAL"],
@@ -92,47 +185,85 @@ SOUND_MODE_MAPPING = {
     "MONO MOVIE": ["MONO MOVIE"],
     "DIRECT": ["DIRECT"],
     "PURE DIRECT": ["PURE_DIRECT", "PURE DIRECT"],
-    "DOLBY DIGITAL": ["DOLBY DIGITAL", "DOLBY D + DOLBY SURROUND",
-                      "DOLBY DIGITAL +", "STANDARD(DOLBY)", "DOLBY SURROUND",
-                      "DOLBY D + +DOLBY SURROUND", "NEURAL", "DOLBY HD",
-                      "DOLBY HD + DOLBY SURROUND", "MULTI IN + DSUR",
-                      "MULTI IN + NEURAL:X", "MULTI IN + DOLBY SURROUND",
-                      "DOLBY D + NEURAL:X", "DOLBY DIGITAL + NEURAL:X",
-                      "DOLBY DIGITAL + + NEURAL:X", "DOLBY ATMOS",
-                      "DOLBY AUDIO - DOLBY SURROUND", "DOLBY TRUEHD",
-                      "DOLBY AUDIO - DOLBY DIGITAL PLUS",
-                      "DOLBY AUDIO - TRUEHD + DSUR",
-                      "DOLBY AUDIO - DOLBY TRUEHD",
-                      "DOLBY AUDIO - TRUEHD + NEURAL:X",
-                      "DOLBY AUDIO - DD + DSUR",
-                      "DOLBY AUDIO - DD+   + NEURAL:X",
-                      "DOLBY AUDIO - DD+   + DSUR",
-                      "DOLBY AUDIO - DOLBY DIGITAL"],
-    "DTS SURROUND": ["DTS SURROUND", "DTS NEURAL:X", "STANDARD(DTS)",
-                     "DTS + NEURAL:X", "MULTI CH IN", "DTS-HD MSTR",
-                     "DTS VIRTUAL:X", "DTS-HD + NEURAL:X", "DTS-HD",
-                     "DTS + VIRTUAL:X", "DTS + DOLBY SURROUND",
-                     "DTS-HD + DOLBY SURROUND", "DTS-HD + DSUR",
-                     "DTS:X MSTR"],
+    "DOLBY DIGITAL": [
+        "DOLBY DIGITAL",
+        "DOLBY D + DOLBY SURROUND",
+        "DOLBY DIGITAL +",
+        "STANDARD(DOLBY)",
+        "DOLBY SURROUND",
+        "DOLBY D + +DOLBY SURROUND",
+        "NEURAL",
+        "DOLBY HD",
+        "DOLBY HD + DOLBY SURROUND",
+        "MULTI IN + DSUR",
+        "MULTI IN + NEURAL:X",
+        "MULTI IN + DOLBY SURROUND",
+        "DOLBY D + NEURAL:X",
+        "DOLBY DIGITAL + NEURAL:X",
+        "DOLBY DIGITAL + + NEURAL:X",
+        "DOLBY ATMOS",
+        "DOLBY AUDIO - DOLBY SURROUND",
+        "DOLBY TRUEHD",
+        "DOLBY AUDIO - DOLBY DIGITAL PLUS",
+        "DOLBY AUDIO - TRUEHD + DSUR",
+        "DOLBY AUDIO - DOLBY TRUEHD",
+        "DOLBY AUDIO - TRUEHD + NEURAL:X",
+        "DOLBY AUDIO - DD + DSUR",
+        "DOLBY AUDIO - DD+   + NEURAL:X",
+        "DOLBY AUDIO - DD+   + DSUR",
+        "DOLBY AUDIO - DOLBY DIGITAL",
+        "DOLBY AUDIO-DSUR",
+    ],
+    "DTS SURROUND": [
+        "DTS SURROUND",
+        "DTS NEURAL:X",
+        "STANDARD(DTS)",
+        "DTS + NEURAL:X",
+        "MULTI CH IN",
+        "DTS-HD MSTR",
+        "DTS VIRTUAL:X",
+        "DTS-HD + NEURAL:X",
+        "DTS-HD",
+        "DTS + VIRTUAL:X",
+        "DTS + DOLBY SURROUND",
+        "DTS-HD + DOLBY SURROUND",
+        "DTS-HD + DSUR",
+        "DTS:X MSTR",
+    ],
     "AURO3D": ["AURO-3D", "AURO-2D SURROUND"],
-    "MCH STEREO": ["MULTI CH STEREO", "MULTI_CH_STEREO", "MCH STEREO",
-                   "MULTI CH IN 7.1"],
+    "MCH STEREO": [
+        "MULTI CH STEREO",
+        "MULTI_CH_STEREO",
+        "MCH STEREO",
+        "MULTI CH IN 7.1",
+    ],
     "STEREO": ["STEREO"],
-    ALL_ZONE_STEREO: ["ALL ZONE STEREO"]}
+    ALL_ZONE_STEREO: ["ALL ZONE STEREO"],
+}
 
 # Receiver sources
-PLAYING_SOURCES = (
-    "Online Music", "Media Server", "iPod/USB", "Bluetooth",
-    "Internet Radio", "Favorites", "SpotifyConnect", "Flickr",
-    "TUNER", "NET/USB", "HDRADIO", "Music Server", "NETWORK", "NET")
-NETAUDIO_SOURCES = (
-    "Online Music", "Media Server", "iPod/USB", "Bluetooth",
-    "Internet Radio", "Favorites", "SpotifyConnect", "Flickr",
-    "NET/USB", "Music Server", "NETWORK", "NET")
+NETAUDIO_SOURCES = {
+    "AirPlay",
+    "Online Music",
+    "Media Server",
+    "iPod/USB",
+    "Bluetooth",
+    "Internet Radio",
+    "Favorites",
+    "SpotifyConnect",
+    "Flickr",
+    "NET/USB",
+    "Music Server",
+    "NETWORK",
+    "NET",
+}
+TUNER_SOURCES = {"Tuner", "TUNER"}
+HDTUNER_SOURCES = {"HD Radio", "HDRADIO"}
+PLAYING_SOURCES = set().union(*[NETAUDIO_SOURCES, TUNER_SOURCES, HDTUNER_SOURCES])
 
 # Image URLs
 STATIC_ALBUM_URL = "http://{host}:{port}/img/album%20art_S.png"
-ALBUM_COVERS_URL = "http://{host}:{port}/NetAudio/art.asp-jpg?{time}"
+ALBUM_COVERS_URL = "http://{host}:{port}/NetAudio/art.asp-jpg?{hash}"
 
 # General URLs
 APPCOMMAND_URL = "/goform/AppCommand.xml"
@@ -207,7 +338,8 @@ DENONAVR_URLS = ReceiverURLs(
     command_netaudio_post=COMMAND_NETAUDIO_POST_URL,
     command_set_all_zone_stereo=COMMAND_SET_ZST_URL,
     command_pause=COMMAND_PAUSE,
-    command_play=COMMAND_PLAY)
+    command_play=COMMAND_PLAY,
+)
 
 ZONE2_URLS = ReceiverURLs(
     appcommand=APPCOMMAND_URL,
@@ -231,7 +363,8 @@ ZONE2_URLS = ReceiverURLs(
     command_netaudio_post=COMMAND_NETAUDIO_POST_URL,
     command_set_all_zone_stereo=COMMAND_SET_ZST_URL,
     command_pause=COMMAND_PAUSE,
-    command_play=COMMAND_PLAY)
+    command_play=COMMAND_PLAY,
+)
 
 ZONE3_URLS = ReceiverURLs(
     appcommand=APPCOMMAND_URL,
@@ -255,10 +388,11 @@ ZONE3_URLS = ReceiverURLs(
     command_netaudio_post=COMMAND_NETAUDIO_POST_URL,
     command_set_all_zone_stereo=COMMAND_SET_ZST_URL,
     command_pause=COMMAND_PAUSE,
-    command_play=COMMAND_PLAY)
+    command_play=COMMAND_PLAY,
+)
 
 # Telnet Commands
-TELNET_EVENTS = ["PW", "MV", "MU", "SI", "MS", "PS"]
+TELNET_EVENTS = {"HD", "MS", "MU", "MV", "NS", "PS", "PW", "SI", "SS", "TF"}
 
 # States
 POWER_ON = "ON"
@@ -290,9 +424,7 @@ MULTI_EQ_MAP = {"0": "Off", "1": "Flat", "2": "L/R Bypass", "3": "Reference"}
 MULTI_EQ_MAP_LABELS = {(value, key) for key, value in MULTI_EQ_MAP.items()}
 
 REF_LVL_OFFSET_MAP = {"0": "0dB", "1": "+5dB", "2": "+10dB", "3": "+15dB"}
-REF_LVL_OFFSET_MAP_LABELS = {
-    (value, key) for key, value in REF_LVL_OFFSET_MAP.items()}
+REF_LVL_OFFSET_MAP_LABELS = {(value, key) for key, value in REF_LVL_OFFSET_MAP.items()}
 
 DYNAMIC_VOLUME_MAP = {"0": "Off", "1": "Light", "2": "Medium", "3": "Heavy"}
-DYNAMIC_VOLUME_MAP_LABELS = {
-    (value, key) for key, value in DYNAMIC_VOLUME_MAP.items()}
+DYNAMIC_VOLUME_MAP_LABELS = {(value, key) for key, value in DYNAMIC_VOLUME_MAP.items()}
