@@ -12,74 +12,81 @@ import inspect
 import logging
 import time
 import xml.etree.ElementTree as ET
-
 from functools import wraps
 from typing import Callable, Coroutine, TypeVar
 
 import httpx
-
 from defusedxml import DefusedXmlException
 from defusedxml.ElementTree import ParseError
 
 from .exceptions import (
-    AvrRequestError,
     AvrForbiddenError,
+    AvrInvalidResponseError,
     AvrNetworkError,
+    AvrRequestError,
     AvrTimoutError,
-    AvrInvalidResponseError)
+)
 
 _LOGGER = logging.getLogger(__name__)
 
-AnyT = TypeVar('AnyT')
+AnyT = TypeVar("AnyT")
 
 
-def async_handle_receiver_exceptions(
-        func: Callable[..., AnyT]) -> Callable[..., AnyT]:
+def async_handle_receiver_exceptions(func: Callable[..., AnyT]) -> Callable[..., AnyT]:
     """
     Handle exceptions raised when calling an Denon AVR endpoint asynchronously.
 
     The decorated function must either have a string variable as second
     argument or as "request" keyword argument.
     """
+
     @wraps(func)
     async def wrapper(*args, **kwargs):
         try:
             return await func(*args, **kwargs)
         except httpx.HTTPStatusError as err:
-            _LOGGER.debug(
-                "HTTP status error on request %s", err.request, exc_info=True)
+            _LOGGER.debug("HTTP status error on request %s", err.request, exc_info=True)
             # Separate handling of 403 errors
             if err.response.status_code == 403:
                 raise AvrForbiddenError(
-                    "HTTPStatusError: {}".format(err), err.request) from err
+                    "HTTPStatusError: {}".format(err), err.request
+                ) from err
             raise AvrRequestError(
-                "HTTPStatusError: {}".format(err), err.request) from err
+                "HTTPStatusError: {}".format(err), err.request
+            ) from err
         except httpx.TimeoutException as err:
             _LOGGER.debug(
-                "HTTP timeout exception on request %s", err.request,
-                exc_info=True)
+                "HTTP timeout exception on request %s", err.request, exc_info=True
+            )
             raise AvrTimoutError(
-                "TimeoutException: {}".format(err), err.request) from err
+                "TimeoutException: {}".format(err), err.request
+            ) from err
         except httpx.NetworkError as err:
             _LOGGER.debug(
-                "Network error exception on request %s", err.request,
-                exc_info=True)
-            raise AvrNetworkError(
-                "NetworkError: {}".format(err), err.request) from err
+                "Network error exception on request %s", err.request, exc_info=True
+            )
+            raise AvrNetworkError("NetworkError: {}".format(err), err.request) from err
         except httpx.RemoteProtocolError as err:
             _LOGGER.debug(
-                "Remote protocol error exception on request %s", err.request,
-                exc_info=True)
+                "Remote protocol error exception on request %s",
+                err.request,
+                exc_info=True,
+            )
             raise AvrInvalidResponseError(
-                "RemoteProtocolError: {}".format(err), err.request) from err
+                "RemoteProtocolError: {}".format(err), err.request
+            ) from err
         except (
-                ET.ParseError, DefusedXmlException, ParseError,
-                UnicodeDecodeError) as err:
+            ET.ParseError,
+            DefusedXmlException,
+            ParseError,
+            UnicodeDecodeError,
+        ) as err:
             _LOGGER.debug(
-                "Defusedxml parse error on request %s", (args, kwargs),
-                exc_info=True)
+                "Defusedxml parse error on request %s", (args, kwargs), exc_info=True
+            )
             raise AvrInvalidResponseError(
-                "XMLParseError: {}".format(err), (args, kwargs)) from err
+                "XMLParseError: {}".format(err), (args, kwargs)
+            ) from err
 
     return wrapper
 
@@ -112,6 +119,7 @@ def set_cache_id(func: Callable[..., AnyT]) -> Callable[..., AnyT]:
     The function must be called with a fix cache_id keyword argument to be able
     to get cached data. This prevents accidential caching of a function result.
     """
+
     @wraps(func)
     def wrapper(*args, **kwargs):
         if kwargs.get("cache_id") is None:
@@ -129,16 +137,18 @@ def run_async_synchronously(async_func: Coroutine) -> Callable:
     own event loop. This is not efficient but it ensures backwards
     compatibility of this library.
     """
+
     def decorator(func: Callable):
         # Check if function is a coroutine
         if not inspect.iscoroutinefunction(async_func):
             raise AttributeError(
-                "Function {} is not a coroutine function".format(async_func))
+                "Function {} is not a coroutine function".format(async_func)
+            )
         # Check if the signature of both functions is equal
         if inspect.signature(func) != inspect.signature(async_func):
             raise AttributeError(
-                "Functions {} and {} have different signatures".format(
-                    func, async_func))
+                "Functions {} and {} have different signatures".format(func, async_func)
+            )
 
         @wraps(func)
         def wrapper(*args, **kwargs):
