@@ -8,7 +8,6 @@ This module implements the handler for volume of Denon AVR receivers.
 """
 
 import logging
-
 from typing import Hashable, Optional, Union
 
 import attr
@@ -18,7 +17,6 @@ from .const import DENON_ATTR_SETATTR, MAIN_ZONE, STATE_ON
 from .exceptions import AvrCommandError, AvrProcessingError
 from .foundation import DenonAVRFoundation
 
-
 _LOGGER = logging.getLogger(__name__)
 
 
@@ -39,21 +37,20 @@ class DenonAVRVolume(DenonAVRFoundation):
     """This class implements volume functions of Denon AVR receiver."""
 
     _volume: Optional[float] = attr.ib(
-        converter=attr.converters.optional(convert_volume),
-        default=None)
+        converter=attr.converters.optional(convert_volume), default=None
+    )
     _muted: Optional[bool] = attr.ib(
-        converter=attr.converters.optional(convert_muted),
-        default=None)
+        converter=attr.converters.optional(convert_muted), default=None
+    )
 
     # Update tags for attributes
     # AppCommand.xml interface
     appcommand_attrs = {
         AppCommands.GetAllZoneVolume: None,
-        AppCommands.GetAllZoneMuteStatus: None}
+        AppCommands.GetAllZoneMuteStatus: None,
+    }
     # Status.xml interface
-    status_xml_attrs = {
-        "_volume": "./MasterVolume/value",
-        "_muted": "./Mute/value"}
+    status_xml_attrs = {"_volume": "./MasterVolume/value", "_muted": "./Mute/value"}
 
     def setup(self) -> None:
         """Ensure that the instance is initialized."""
@@ -61,16 +58,14 @@ class DenonAVRVolume(DenonAVRFoundation):
         for tag in self.appcommand_attrs:
             self._device.api.add_appcommand_update_tag(tag)
 
-        self._device.telnet_api.register_callback("MV", self._volume_callback)
-        self._device.telnet_api.register_callback("MU", self._mute_callback)
+        self._device.telnet_api.register_callback("MV", self._async_volume_callback)
+        self._device.telnet_api.register_callback("MU", self._async_mute_callback)
 
         self._is_setup = True
 
-    async def _volume_callback(
-            self,
-            zone: str,
-            event: str,
-            parameter: str) -> None:
+    async def _async_volume_callback(
+        self, zone: str, event: str, parameter: str
+    ) -> None:
         """Handle a volume change event."""
         if self._device.zone != zone:
             return
@@ -82,11 +77,7 @@ class DenonAVRVolume(DenonAVRFoundation):
             fraction = 0.1 * float(parameter[2])
             self._volume = -80.0 + whole_number + fraction
 
-    async def _mute_callback(
-            self,
-            zone: str,
-            event: str,
-            parameter: str) -> None:
+    async def _async_mute_callback(self, zone: str, event: str, parameter: str) -> None:
         """Handle a muting change event."""
         if self._device.zone != zone:
             return
@@ -94,36 +85,35 @@ class DenonAVRVolume(DenonAVRFoundation):
         self._muted = parameter
 
     async def async_update(
-            self,
-            global_update: bool = False,
-            cache_id: Optional[Hashable] = None) -> None:
+        self, global_update: bool = False, cache_id: Optional[Hashable] = None
+    ) -> None:
         """Update volume asynchronously."""
         # Ensure instance is setup before updating
         if self._is_setup is False:
             self.setup()
 
         # Update state
-        await self.async_update_volume(
-            global_update=global_update, cache_id=cache_id)
+        await self.async_update_volume(global_update=global_update, cache_id=cache_id)
 
     async def async_update_volume(
-            self,
-            global_update: bool = False,
-            cache_id: Optional[Hashable] = None):
+        self, global_update: bool = False, cache_id: Optional[Hashable] = None
+    ):
         """Update volume status of device."""
         if self._device.use_avr_2016_update is True:
             await self.async_update_attrs_appcommand(
-                self.appcommand_attrs, global_update=global_update,
-                cache_id=cache_id)
+                self.appcommand_attrs, global_update=global_update, cache_id=cache_id
+            )
         elif self._device.use_avr_2016_update is False:
             urls = [self._device.urls.status]
             if self._device.zone == MAIN_ZONE:
                 urls.append(self._device.urls.mainzone)
             await self.async_update_attrs_status_xml(
-                self.status_xml_attrs, urls, cache_id=cache_id)
+                self.status_xml_attrs, urls, cache_id=cache_id
+            )
         else:
             raise AvrProcessingError(
-                "Device is not setup correctly, update method not set")
+                "Device is not setup correctly, update method not set"
+            )
 
     ##############
     # Properties #
@@ -152,13 +142,11 @@ class DenonAVRVolume(DenonAVRFoundation):
     ##########
     async def async_volume_up(self) -> None:
         """Volume up receiver via HTTP get command."""
-        await self._device.api.async_get_command(
-            self._device.urls.command_volume_up)
+        await self._device.api.async_get_command(self._device.urls.command_volume_up)
 
     async def async_volume_down(self) -> None:
         """Volume down receiver via HTTP get command."""
-        await self._device.api.async_get_command(
-            self._device.urls.command_volume_down)
+        await self._device.api.async_get_command(self._device.urls.command_volume_down)
 
     async def async_set_volume(self, volume: float) -> None:
         """
@@ -174,16 +162,15 @@ class DenonAVRVolume(DenonAVRFoundation):
         volume = round(volume * 2) / 2.0
 
         await self._device.api.async_get_command(
-            self._device.urls.command_set_volume.format(volume=volume))
+            self._device.urls.command_set_volume.format(volume=volume)
+        )
 
     async def async_mute(self, mute: bool) -> None:
         """Mute receiver via HTTP get command."""
         if mute:
-            await self._device.api.async_get_command(
-                self._device.urls.command_mute_on)
+            await self._device.api.async_get_command(self._device.urls.command_mute_on)
         else:
-            await self._device.api.async_get_command(
-                self._device.urls.command_mute_off)
+            await self._device.api.async_get_command(self._device.urls.command_mute_off)
 
 
 def volume_factory(instance: DenonAVRFoundation) -> DenonAVRVolume:
